/**************************************************************************//**
*   @file   ad8403.h
*   @brief  Header file of AD8403 Driver for NIOS processor.
*   @author DBogdan (dragos.bogdan@analog.com)
*
*******************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 158
******************************************************************************/
#ifndef _AD8403_H_
#define _AD8403_H_

#ifdef AD8403_GLOBALS
	#define AD8403_EXT extern volatile
#else
	#define AD8403_EXT volatile
#endif

/*****************************************************************************/
/* Include Files                                                             */
/*****************************************************************************/
#include "adi.h"
#if (USE_AD8403 == 1)

/*****************************************************************************/
/* SPI Configuration                                                         */
/*****************************************************************************/
#define AD8403_SPI		SPI_1_P0_BASE
#define AD8403_SPI_CFG	(SPI1_ena | SPI1_phase)

/*****************************************************************************/
/* GPIO                                                                      */
/*****************************************************************************/
#define GPIO_RESET		(1<<1)	// Active Low Input. Terminal A open circuit.
								// Shutdown controls Variable Resistor 1 through Variable Resistor 4.
#define GPIO_MUXA0		(1<<5)	// A0 input of the ADG658 circuit.
#define GPIO_SHDN		(1<<3)	// Active Low Reset to Midscale. Sets RDAC registers to 80H.
#define GPIO_MUXA1		(1<<6)	// A1 input of the ADG658 circuit.
#define GPIO_MUXA2		(1<<7)	// A2 input of the ADG658 circuit.

/*****************************************************************************/
/* RDAC Addresses                                                            */
/*****************************************************************************/
#define RDAC1_ADDRESS	0x0000		// RDAC1 address.
#define RDAC2_ADDRESS	0x0100		// RDAC2 address.
#define RDAC3_ADDRESS	0x0200		// RDAC3 address.
#define RDAC4_ADDRESS	0x0300		// RDAC4 address.

/*****************************************************************************/
/* Monitored variables declarations                                          */
/*****************************************************************************/
AD8403_EXT uCProbeDataUnion AD8403_data[21];// Used to store the values for uC-Probe communication.
#endif //(USE_AD8403 == 1)

/*****************************************************************************/
/* Functions Prototypes                                                      */
/*****************************************************************************/
int AD8403_Init(void); 						// Initializes the communication with the device.
int AD8403_UpdateParameters(void);			// Updates the device's monitored and controlled parameters.
void AD8403_DelayMs(unsigned int ms);		// Creates a delay.
void AD8403_TxSpi(unsigned int value);	// Transmits 16 bits on SPI.
#endif /* _AD8403_H_ */
